==> bigloo_1.9c.orig.tar.gz: bigloo1.9c/comptime/Init/extend.scm <==
;* --------------------------------------------------------------------*/
;*    Copyright (c) 1992-1998 by Manuel Serrano. All rights reserved.  */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \   /  '                               */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome. Send them to                                          */
;*        Manuel Serrano -- Manuel.Serrano@unice.fr                    */
;*-------------------------------------------------------------------- */
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime1.9/Init/extend.scm          */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Fri Oct 28 08:37:41 1994                          */
;*    Last change :  Fri May 31 07:54:57 1996 (serrano)                */
;*    -------------------------------------------------------------    */
;*    La lecture des extensions (isole'es pour ne pas avoir le pbm     */
;*    des PRIMOPs trop nombreuses).                                    */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module init_extend
    (export (load-extend ::bstring))
    (import engine_param
	    tools_file))

;*---------------------------------------------------------------------*/
;*    load-extend ...                                                  */
;*---------------------------------------------------------------------*/
(define (load-extend extend-name)
   (let ((fname (find-file/path extend-name (list *lib-dir*))))
      (if fname
	  (loadq fname)
	  (error "parse-args" "Can't find extend file" extend-name))))

==> bigloo_2.8c.orig.tar.gz: bigloo2.8c/comptime/Init/extend.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime/Init/extend.scm             */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Fri Oct 28 08:37:41 1994                          */
;*    Last change :  Mon May 15 07:27:19 2000 (serrano)                */
;*    Copyright   :  1992-2000 Manuel Serrano, see LICENSE file        */
;*    -------------------------------------------------------------    */
;*    La lecture des extensions (isole'es pour ne pas avoir le pbm     */
;*    des PRIMOPs trop nombreuses).                                    */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module init_extend
    (export (load-extend ::bstring))
    (import engine_param))

;*---------------------------------------------------------------------*/
;*    load-extend ...                                                  */
;*---------------------------------------------------------------------*/
(define (load-extend extend-name)
   (let ((fname (find-file/path extend-name *lib-dir*)))
      (if fname
	  (loadq fname)
	  (error "parse-args" "Can't find extend file" extend-name))))
